Learn R Programming

atpolR (version 0.1.1)

check_atpol_square: Reverse engineering of published ATPOL grids

Description

check_atpol_square() do a reverse engineering of published ATPOL grids species, especially those published in zajacAtlasRozmieszczeniaRoslin2001;textualatpolR

Usage

check_atpol_square(centroid, raster, distance)

Value

"YES" or "?" for given SF point

Arguments

centroid

Simple Feature point geometry for which the check is performed, usually it corresponds to centroid of ATPOL 10km x 10km grid

raster

geocoded raster, it has to be in EPSG:2180 projection

distance

st_buffer distance from centroid point for which the check is done, default 1200 m

References