Learn R Programming

atpolR (version 0.1.1)

grid_to_latlon: grid_to_latlon converts the ATPOL grid to latitude and longitude. With xoffset = 0 and yoffset = 0 parameters it returns coordinates of the upper left corner of the grid.

Description

grid_to_latlon converts the ATPOL grid to latitude and longitude. With xoffset = 0 and yoffset = 0 parameters it returns coordinates of the upper left corner of the grid.

Usage

grid_to_latlon(grid, xoffset = 0.5, yoffset = 0.5)

Value

latitude and longitude of ATPOL grid (default centroid) as pair of numerics

Arguments

grid

An ATPOL grid, ex. "GF2345".

xoffset

An offset in X, where 0 is for left, and 1 for right side of the grid. The default value is 0.5, which corresponds to middle of the grid.

yoffset

An offset in Y, where 0 is for top, and 1 for bottom side of the grid. The default value is 0.5, which corresponds to middle of the grid.

References

https://atpol.sourceforge.io/

Examples

Run this code
grid_to_latlon("BE21")
grid_to_latlon("BE21", 0, 0)

Run the code above in your browser using DataLab