grid_to_latlon: grid_to_latlon converts the ATPOL grid to latitude and longitude.
With xoffset = 0 and yoffset = 0 parameters it returns coordinates of the upper left corner of the grid.
Description
grid_to_latlon converts the ATPOL grid to latitude and longitude.
With xoffset = 0 and yoffset = 0 parameters it returns coordinates of the upper left corner of the grid.